@@ -187,7 +187,7 @@ Any given mail address can match a range of face images, from most specific (suc
         {faces(xFaceEnabled) xFaceEnabled ON {Use X-Face headers}
 	"If a message contains an X-Face header, display the image encoded into the header."}
 
-	{faces(xfaceProg) xfaceProg {} {X-Face command}
+	{faces(xfaceProg) xfaceProg {uncompface -X} {X-Face command}
 "A command to convert an X-Face: header line into a displayable X11 bitmap.
 
 If you've patch uncompface, this can be:	uncompface -X
@@ -493,6 +493,28 @@ is interactive, then run it from exmh-async:
 exmh-async xterm -e ispell
 (This is faked - exmh-async isn't really used.  Instead a temporary
 wish script is used.)"}
+    {sedit(notifySuccess) seditNotifySuccess OFF {Notify on sucessful delivery}
+"This lets you say whether you would like to be informed (via an email
+message) when your mail has been delivered.  For it to work you will
+need a hacked over version of MH, and an SMTP server which supports
+the IETF's Delivery Status Notification SMTP extension!"}
+    {sedit(notifyFailure) seditNotifyFailure OFF {Notify if delivery fails}
+"This lets you say whether you would like to be informed (via an email
+message) when your mail has been not been delivered because of an
+error.  For it to work you will need a hacked over version of MH, and
+an SMTP server which supports the IETF's Delivery Status Notification
+SMTP extension!"}
+    {sedit(notifyDelay) seditNotifyDelay OFF {Notify if delivery is delayed}
+"This lets you say whether you would like to be informed (via an email
+message) when delivery of your mail has been been delayed.  For it to
+work you will need a hacked over version of MH, and an SMTP server
+which supports the IETF's Delivery Status Notification SMTP extension!"}
+    {sedit(notifyRet) seditNotifyRet OFF {Return full message}
+"This lets you say whether you would like delivery status notifications
+to take the form of full copies of the original message, or just the
+headers - the default.  For it to work, you will need a hacked over
+version of MH, and an SMTP server which supports the IETF's Delivery
+Status Notification SMTP extension!"}
     {sedit(autosaveInterval)   seditAutosaveInterval 60 {Seconds between auto saves}
 "This is the interval, in seconds, between automatic saves of 
 the message being edited.  Set to 0 to disable autosaving."}
@@ -630,7 +652,8 @@ Here you can select, which version to use in these cases.
     Preferences_Add "General PGP Interface" "" {
     {pgp(keeppass) pgpKeepPass ON {Keep PGP passphrase}
 "Exmh tries to remember your passphrase between PGP
-invocations. But the passphrase is then kept in a global
+invocations. If pgpExtPass is on, exmh will use an external passphrase
+cache program; otherwise the passphrase is then kept in a global
 variable, which is not safe, because of \"send\"'s power.
 If you turn this feature off, exmh will use xterm to run
 pgp so that it doesn't have to deal with the passphrase at all." }
@@ -649,7 +672,7 @@ this time period, in minutes, has elapsed." }
 {pgp(extpass) pgpExtPass OFF {Use external passphrase cache}
 "If this is enabled, then exmh will use an external program to retrieve 
 your passphrase when needed. pgpKeepPass and pgpPassTimeout will 
-be ignored."}
+be ignored. pgpExtPass has no effect if pgpKeepPass is not active. "}
 {pgp(getextcmd) pgpGetExtCmd {/usr/bin/q-client get %s} {Method to query external passphrase cache}
 "This external program is used to retrieve the passphrase for your key,
 if pgpExtPass is active. The passphrase is expected on stdout.
