@@ -1,4 +1,4 @@
-# $Header: /cvsroot/exmh/exmh/lib/glimpse.tcl,v 1.5 2003/02/11 05:49:49 sysphrog Exp $
+# $Header: /cvsroot/exmh/exmh/lib/glimpse.tcl,v 1.6 2004/07/26 17:41:19 sysphrog Exp $
 #
 # link glimpse to exmh to provide full text searching within and
 # across folders faster but less thoroughly than pick
@@ -485,7 +485,7 @@ proc Glimpse_Index { } {
     }
 
     if ![file isdirectory $mhProfile(path)/.glimpse] {
-	if [catch {exec mkdir $mhProfile(path)/.glimpse} err] {
+	if [catch {file mkdir $mhProfile(path)/.glimpse} err] {
 	    set glimpse(info) $err
 	    return
 	}
@@ -638,7 +638,7 @@ proc MakeDir { path } {
 	if ![file isdirectory [file dirname $path]] {
 	    MakeDir [file dirname $path]
 	}
-	exec mkdir $path
+	file mkdir $path
     }
 }
 
@@ -662,7 +662,7 @@ proc Glimpse_Batch { i cmd } {
 	set myname [winfo name .]
 	puts $out "catch \{exec $cmd\} out"
 	puts $out "catch \{send [list $myname] \[list Glimpse_BatchDone \$out\]\}"
-	puts $out "exec rm $path"
+	puts $out "file delete -force $path"
 	puts $out exit
 	close $out
 	set glimpse(done) {}
@@ -718,7 +718,7 @@ proc Glimpse_Delete { f } {
 	    append rmsg "$info"
 	} else {
 	    append rmsg "glimpse index files deleted"
-	    catch {exec rmdir $idir}
+	    catch {file delete $idir}
 	}
     }
     return $rmsg
