@@ -21,7 +21,7 @@ proc Mime_Init {} {
     # Make sure Metamail is on the path
     set hit 0
     foreach dir [split $env(PATH) :] {
-	if {[string compare $dir $mime(dir)] == 0} {
+	if {[string compare $dir $mime(dir)] == 0 && [string length $mime(dir)]} {
 	    set hit 1
 	    break
 	}
@@ -29,23 +29,24 @@ proc Mime_Init {} {
     if {! $hit} {
 	set env(PATH) $mime(dir):$env(PATH)
     }
-    set mime(encode) mimencode
-    foreach dir [split $env(PATH) :] {
-	if {[file executable $dir/mimencode]} {
-	    set mime(encode) mimencode
-	    break
-	}
-	if {[file executable $dir/mmencode]} {
-	    set mime(encode) mmencode
-	    break
-	}
-    }
 
     set mime(init) 1
     set mime(seed) 1
     set mime(junkfiles) {}
     set mime(stop) 0
 
+    foreach dir [split $env(PATH) :] {
+      if {[file executable $dir/mimencode]} {
+          set mime(encode) mimencode
+          break
+      }
+      if {[file executable $dir/mmencode]} {
+          set mime(encode) mmencode
+          break
+      }
+    }
+    # If mime(encode) is not set, we use a fallback path
+
     set types [concat [option get . mimeTypes {}] [option get . mimeUTypes {}]]
     Exmh_Debug MimeTypes $types
     set mime(showproc,default)			Mime_ShowDefault
@@ -135,7 +136,7 @@ warning about a large message and STOP button."}
 	{FTP access method}
 "Sometimes the automatic FTP transfer fails because of
 problems logging into the remote host.	This option lets
-you try a few different approachs to find the one that
+you try a few different approaches to find the one that
 works for you:
 expect - use the ftp.expect script to download the file.
 ftp - use ftp and feed user and password to it via a pipe.
@@ -184,7 +185,7 @@ The full header is: Content-Disposition: attachment; filename=\"...\"."}
 "This controls whether or not attachement filename
 will be translated into a suitable DOS 8.3 representation."}
 	{mime(mdnTo) dispositionNotificationTo {} {Disposition Notification To}
-"The address where you want MDN receipts to end up.  This normally your
+"The address where you want MDN receipts to end up.  This is normally your
 own email address."}
 	{mime(mdnSend) dispositionNotificationSend
          {CHOICE never deny {ask user} auto/ask auto/ignore } 
@@ -211,6 +212,10 @@ The following line makes exmh display the text/plain part in favour
 of the text/html part if both are present in a multipart/alternative:
 
 text/plain text/html"}
+{mime(saveDir) mimeSaveDir {~/attachments} {Save directory for attachments}
+"This defines the directory to use when saving attachments.  Attachments
+are saved by extracting them from the message and replacing the
+attachment with a message/external-body reference to the saved file."}
     }
     set i 0
     foreach char {A B C D E F G H I J K L M N O P Q R S T U V W X Y Z \
@@ -312,12 +317,17 @@ proc MimeHeader {part contentType encoding} {
     if {[string compare $type "text"] == 0} {
 	set type text/plain
     }
+    # Paranoia time - sanitize these just in case...
+    # Yes, we're ignoring the rfc2045 sec 5.1 definition of 'tspecials'
     set mimeHdr($part,hdr,content-type) $contentType
+    regsub -all {[^-/[:print:]]} $type {} type
     set mimeHdr($part,type) $type
+    regsub -all {[^-[:print:]]} $encoding {} encoding
     set mimeHdr($part,encoding) $encoding
     set mimeHdr($part,params) {}
     foreach sub [lrange $params 1 end] {
 	if [regexp {([^=]+)=(.+)} $sub match key val] {
+	    regsub -all {[^-/[:print:]]} $key {} key
 	    set key [string trim [string tolower $key]]
 	    set val [string trim $val]
 	    # Allow single as well as double quotes
@@ -336,9 +346,8 @@ proc MimeHeader {part contentType encoding} {
 	set mimeHdr($part,param,charset) \
 		[string tolower $mimeHdr($part,hdr,x-sun-charset)]
     }
-    # infer the name from the filename:
-    if {[info exists mimeHdr($part,param,filename)] &&
-      ![info exists mimeHdr($part,param,name)]} {
+    # infer the name from the filename= in preference to a name=
+    if {[info exists mimeHdr($part,param,filename)]} {
       set mimeHdr($part,param,name) $mimeHdr($part,param,filename)
     }
     return $type
@@ -617,11 +626,20 @@ proc MimeClose { fileIO } {
 proc MimeSetDisplayFlag {part} {
     global mime mimeHdr msg uri
 
-    # Flag to determine if we display the part or not.	We display it
+    # Flag to determine if we display the part or not. We don't display it
+    # if we've been told not to (yes, we check this first, as RFC2183, sec 2.9
+    # says it's legal even on a multipart). Otherwise, we display it
     # if it's a multipart (other than multipart/parallel).  We display 
     # it if it's an image (unless we aren't supposed to do that.  Otherwise,
-    # we display it unless we've been told not to or it's too darn big.
+    # we display it unless it's too darn big.
     if {[info exists mimeHdr($part,file)]} {
+	if {[info exists mimeHdr($part,hdr,content-disposition)]} {
+	    set disp [split $mimeHdr($part,hdr,content-disposition) \;]
+	    if [regexp {ancillary|attachment} [lindex $disp 0]] {
+		set mimeHdr($part,display) 0
+		return
+	    }
+	}
 	if [regexp {^multipart} $mimeHdr($part,type)] {
 	    set mimeHdr($part,display) \
 		[expr ![regexp {parallel$} $mimeHdr($part,type)]]
@@ -638,13 +656,6 @@ proc MimeSetDisplayFlag {part} {
 	    Exmh_Debug "vcard: not displaying"
 	    return
 	}
-	if {[info exists mimeHdr($part,hdr,content-disposition)]} {
-	    set disp [split $mimeHdr($part,hdr,content-disposition) \;]
-	    if [regexp {ancillary} [lindex $disp 0]] {
-		set mimeHdr($part,display) 0
-		return
-	    }
-	}
 	if ![info exists mimeHdr($part,display)] {
 	    set mimeHdr($part,display) \
 		[expr {[file exists $mimeHdr($part,file)] && \
@@ -1432,23 +1443,46 @@ proc MimeDecode {fileName name encoding text} {
     }
     if [catch {
 	set out [open $name w 0600]
+        fconfigure $out -encoding binary        ;# No CRLF translations, please
 	switch -regexp -- $encoding {
 	    (8|7)bit {
 		Exmh_Debug "cat > $name"
 		exec cat $fileName >@ $out
 	    }
+	    quoted-printable -
 	    base64 {
-		if $text {
-		    Exmh_Debug "$mime(encode) -u -b -p > $name"
-		    exec $mime(encode) -u -b -p $fileName >@ $out
-		} else {
-		    Exmh_Debug "$mime(encode) -u -b > $name"
-		    exec $mime(encode) -u -b $fileName >@ $out
-		}
-	    }
-	    quoted-printable {
-		Exmh_Debug "$mime(encode) -u -q > $name"
-		exec $mime(encode) -u -q $fileName >@ $out
+                if {[info exist mime(encode)]} {
+                  if {$encoding == "base64"} {
+                    exec $mime(encode) -u -b $fileName >@ $out
+                  } else {
+                    exec $mime(encode) -u -q $fileName >@ $out
+                  }
+                } else {
+                  # Replace use of mimencode with Tcl versions.
+                  # This is noticably slower.  We should also
+                  # figure out how to use mhstore here
+                  set in [open $fileName]
+                  set line_cnt 0  ;# Accumulate lines before calling the decoder
+                  set buffer ""
+                  while {[gets $in line] >= 0} {
+                      append buffer $line\n
+                      incr line_cnt
+                      if {$line_cnt > 1000} {
+                          if {$encoding == "base64"} {
+                              puts -nonewline $out [Base64_Decode $buffer]
+                          } else {
+                              puts -nonewline $out [::mime::qp_decode $buffer]
+                          }
+                          set line_cnt 0
+                          set buffer ""
+                      }
+                  }
+                  if {$encoding == "base64"} {
+                      puts -nonewline $out [Base64_Decode $buffer]
+                  } else {
+                      puts -nonewline $out [::mime::qp_decode $buffer]
+                  }
+                }
 	    }
 	    .*uue.* {
 		Exmh_Debug "uudecode -p > $name"
@@ -1561,7 +1595,7 @@ proc MimeLocalFileTransfer {tkw part} {
     set mimeHdr($part=1,file) [file join $dir $name]
 }
 proc MimeFTPTransfer {tkw part} {
-    global mime mimeHdr
+    global mime mimeHdr install
 
     set site $mimeHdr($part,param,site)
     set directory $mimeHdr($part,param,directory)
@@ -1584,7 +1618,7 @@ proc MimeFTPTransfer {tkw part} {
 	    case $mime(ftpMethod) {
 		expect {
 		    Exmh_Status "ftp.expect $site ..."
-		    busy exec ftp.expect $site $directory $theirname $myname $mode
+		    busy exec $install(dir,bin)/ftp.expect $site $directory $theirname $myname $mode
 		}
 		ftp* {
 		    Exmh_Status "$mime(ftpCommand) -n $site ..."
@@ -2148,7 +2182,20 @@ proc MimeParseSingle {tkw part fileIO } {
 		[expr {$mime(enabled) && 
 		       [info exists mimeHdr(0=1,hdr,content-type)]}]
 	}
-
+        #
+        # Skip through blank lines looking for the start of a PGP message
+        # Old code used to just consume a single line
+        # (Based on a patch from Joel Hatton)
+        #
+        set firstLine ""
+        while {! [eof $fileIO]} {
+            set firstLinePosition [tell $fileIO]
+            gets $fileIO firstLine
+            if { ! [regexp {(?n)^\s*$} $firstLine ] } {
+              break
+            }
+        }
+        if [regexp $miscRE(beginpgp) $firstLine] { set mimeHdr($part,decode) 1 }
     } else {
 	Exmh_Status "Warning - no headers" warn
 	set firstLine $line
@@ -2156,11 +2203,6 @@ proc MimeParseSingle {tkw part fileIO } {
 	set mimeHdr($part,encoding) [set encoding 8bit]
 	set mimeHdr($part,params) {}
     }
-    if {![info exists firstLine]} {
-	set firstLinePosition [tell $fileIO]
-	gets $fileIO firstLine
-	if [regexp $miscRE(beginpgp) $firstLine] { set mimeHdr($part,decode) 1 }
-    }
     if {$numBytes >= 0} {
 	if {$fast && [string compare $type text/plain] == 0 &&
 	    [regexp {[78]bit} $encoding] &&
@@ -2330,8 +2372,9 @@ proc Mime_SavePiece {part type} {
     set name [FSBox "Save $type to:" $default]
     if {$name != {}} {
 	if [catch {
-	    exec cp $fileName $name
-	    exec chmod $mhProfile(msg-protect) $name
+	    file copy -- $fileName $name
+            # Leading zero to ensure octal interpretation
+	    file attributes $name -permissions 0$mhProfile(msg-protect)
 	} err] {
 	    Exmh_Status $err
 	}
@@ -2808,14 +2851,7 @@ proc Mime_EudoraFilename {name} {
 }
 
 proc Mime_MakeBoundary { end } {
-
-    # Old boundary was made by
-    # regsub -all "\[ \x7f-\xff\]" [exec date] _ date
-    # This way works at least with GNU date.
-
-    regsub -all {[^0-9]|[0-9][0-9][0-9][0-9]} [exec date] {} boundary
-    regsub {^0*} $boundary {} boundary	;# No octal interpretation, please
-    set boundary [expr $boundary*[pid]]
+    set boundary [clock seconds]_[pid]
     return "==_Exmh_$boundary$end"
 }
 proc Mime_Magic { fileName } {
@@ -2864,3 +2900,42 @@ proc Mime_ShowXApp { tkw part } {
      [list Mime_SavePiece $part $mimeHdr($part,type)]
     $tkw insert insert \n
 }
+
+proc Mime_SaveAttachments {{dir {}}} {
+    global msg mime install
+
+    if {$dir == ""} {
+      set dir $mime(saveDir)
+    }
+    file mkdir $dir
+    if {[catch {
+      exec $install(dir,bin)/exmh-strip $msg(path) $dir
+    } err]} {
+        if {[regexp {(.*) exists} $err _ file]} {
+            if {[Mime_SaveAttachmentRetry $file]} {
+                file delete $file
+                exec $install(dir,bin)/exmh-strip $msg(path) $dir
+            }
+        }
+    }
+    Msg_ShowCurrent
+}
+proc Mime_SaveAttachmentRetry {file} {
+    global exwin mime
+    set f [frame $exwin(mtext).save_err -bd 2 -relief ridge]
+
+    message $f.msg1 -text "File Exists\n$file\nDelete and retry?" -aspect 1000
+    pack $f.msg1 -side top -fill both
+
+    set b1 [frame $f.but -bd 10 -relief flat]
+    pack $b1 -side top
+
+    set mime(retry_save) 0
+    button $b1.cancel -text "Cancel" -command {destroy $exwin(mtext).save_err}
+    button $b1.ok -text "OK" -command {set mime(retry_save) 1; destroy $exwin(mtext).save_err}
+    pack $b1.cancel $b1.ok -side left -padx 3
+
+    Widget_PlaceDialog $exwin(mtext) $f
+    tkwait window $f
+    return $mime(retry_save)
+}
