@@ -41,7 +41,7 @@ proc Preferences_Init { userDefaults appDefaults } {
     set pref(localDefaults) \
 	"[file dirname $appDefaults]/local.[file tail $appDefaults]"
 
-    catch {exec mkdir -p [glob ~]/.exmh}
+    catch {file mkdir [glob ~]/.exmh}
 
     if {[file exists [glob ~]/.exmh-defaults] 
 	&& ![file exists $userDefaults]} { 
@@ -100,31 +100,31 @@ $movedFiles
 proc PreferencesDoCopyFiles { } {
     if {[file exists [glob ~]/.exmh-defaults] 
 	&& ![file exists [glob ~]/.exmh/exmh-defaults]} {
-	catch {exec cp -r [glob ~]/.exmh-defaults [glob ~]/.exmh/exmh-defaults}
+	catch {file copy [glob ~]/.exmh-defaults [glob ~]/.exmh/exmh-defaults}
 	append movedList ".exmh-defaults\n"
     }
 	
     if {[file exists [glob ~]/.exmh-defaults-mono]
         && ![file exists [glob ~]/.exmh/exmh-defaults-mono]} {
-        catch {exec cp -r [glob ~]/.exmh-defaults-mono [glob ~]/.exmh/exmh-defaults-mono}
+        catch {file copy [glob ~]/.exmh-defaults-mono [glob ~]/.exmh/exmh-defaults-mono}
         append movedList ".exmh-defaults-mono\n"
     }
 
     if {[file exists [glob ~]/.exmh-defaults-color]
         && ![file exists [glob ~]/.exmh/exmh-defaults-color]} {
-        catch {exec cp -r [glob ~]/.exmh-defaults-color [glob ~]/.exmh/exmh-defaults-color}
+        catch {file copy [glob ~]/.exmh-defaults-color [glob ~]/.exmh/exmh-defaults-color}
         append movedList ".exmh-defaults-color\n"
     }
 
     if {[file exists [glob ~]/.exmh_addrs] 
 	&& ![file exists [glob ~]/.exmh/exmh_addrs]} {
-	catch {exec cp -r [glob ~]/.exmh_addrs [glob ~]/.exmh/exmh_addrs}
+	catch {file copy [glob ~]/.exmh_addrs [glob ~]/.exmh/exmh_addrs}
         append movedList ".exmh_addrs\n"
     }
 
     if {[file exists [glob ~]/.exmh_addrs.bak] 
 	&& ![file exists [glob ~]/.exmh/exmh_addrs.bak]} {
-	catch { exec cp -r [glob ~]/.exmh_addrs.bak [glob ~]/.exmh/exmh_addrs.bak}
+	catch { file copy [glob ~]/.exmh_addrs.bak [glob ~]/.exmh/exmh_addrs.bak}
         append movedList ".exmh_addrs.bak\n"
     }
     
@@ -136,13 +136,13 @@ proc PreferencesDoCopyFiles { } {
     
     if {[file exists [glob ~]/.exmhbindings] 
 	&& ![file exists [glob ~]/.exmh/exmhbindings]} {
-	catch { exec cp -r [glob ~]/.exmhbindings [glob ~]/.exmh/exmhbindings}
+	catch { file copy [glob ~]/.exmhbindings [glob ~]/.exmh/exmhbindings}
         append movedList ".exmhbindings\n"
     }
     
     if {[file exists [glob ~]/.exmhsedit] 
 	&& ![file exists [glob ~]/.exmh/exmhsedit]} {
-	catch { exec cp -r [glob ~]/.exmhsedit [glob ~]/.exmh/exmhsedit}
+	catch { file copy [glob ~]/.exmhsedit [glob ~]/.exmh/exmhsedit}
         append movedList ".exmhsedit\n"
     }
     catch {destroy .newprefs}
@@ -309,6 +309,28 @@ proc Preferences_Dialog {} {
 		set maxWidth $len
 	    }
 	}
+        FontWidget listbox $body.listbox \
+            -exportselection 0 \
+            -selectmode single \
+            -width $maxWidth \
+            -yscrollcommand "$body.scrollbar set"
+
+        scrollbar $body.scrollbar \
+                -command "$body.listbox yview"
+
+        $body.listbox insert end "The Top Ten"
+        foreach x [lsort [concat $pref(panes) Fonts]] {
+            if {$x != "The TopTen"} {
+              $body.listbox insert end $x
+            }
+        }
+        bind $body.listbox <Button-1> {PreferencesListboxHit %W %y}
+
+        pack $body.scrollbar -side right -fill y
+        pack $body.listbox -side left -fill both -expand true
+
+if {0} {
+  # Old Button List
 	Widget_AddBut $body font Fonts Font_Dialog	{top}
 	$body.font configure -width $maxWidth
 	set i 0
@@ -318,9 +340,19 @@ proc Preferences_Dialog {} {
 	    $body.but$i configure -width $maxWidth
 	    incr i
 	}
+}
+
 	wm protocol .pref WM_DELETE_WINDOW PreferencesDelete
     }
 }
+proc PreferencesListboxHit {listbox y} {
+  set id [$listbox get @0,$y]
+  if {$id == "Fonts"} {
+      Font_Dialog
+  } else {
+      PreferencesSectionDialog $id
+  }
+}
 
 proc PreferencesSectionDialog { id } {
     global pref env
