@@ -53,7 +53,8 @@ proc SeqWinToggle {args} {
 	    focus $exwin(mtext)
 	}
 	wm protocol .sequences WM_DELETE_WINDOW SeqWinDeleted
-	catch {Flist_FindSeqs 1}
+        # Flist_FindSeqs won't do anything until we are fully initialized
+        catch {Flist_FindSeqs 1}
     } elseif {!$seqwin(on) && [winfo exists .sequences]} {
 	destroy .sequences
     }
@@ -110,14 +111,15 @@ proc SeqWinShowSeqPane {seq} {
 	set num $flist(totalcount,$seq)
 	if {$num <= 0} {
 	    SeqWinEmptyMsg $seq
-	    if {[lsearch $seqwin(alwaysshow) $seq] < 0} {
+	    if {[patlsearch $seqwin(alwaysshow) $seq] < 0} {
 		if {[winfo ismapped .sequences.pane$seq]} {
 		    SeqWinHideSeqPane $seq
 		}
 	    }
 	}
-	if {[lsearch $seqwin(nevershow) $seq] < 0} {
-	    if {($num > 0) || ([lsearch $seqwin(alwaysshow) $seq] >= 0)} {
+	if {[patlsearch $seqwin(show) $seq] >= 0 ||
+            [patlsearch $seqwin(nevershow) $seq] < 0} {
+	    if {($num > 0) || ([patlsearch $seqwin(alwaysshow) $seq] >= 0)} {
 		if {![winfo ismapped .sequences.pane$seq]} {
 		    if {$seqwin(orientation) == "Horizontal"} {
 			pack .sequences.pane$seq -side left -anchor n -fill y
@@ -156,9 +158,10 @@ proc SeqWinFixShowList {args} {
 	if {![info exists flist(totalcount,$seq)]} {
 	    set flist(totalcount,$seq) 0
 	}
-	if {([lsearch $seqwin(alwaysshow) $seq] >= 0) ||
+	if {([patlsearch $seqwin(alwaysshow) $seq] >= 0) ||
 	    (($flist(totalcount,$seq) > 0) && 
-	     ([lsearch $seqwin(nevershow) $seq] < 0))} {
+	     ([patlsearch $seqwin(show) $seq] >= 0 ||
+              [patlsearch $seqwin(nevershow) $seq] < 0))} {
 	    SeqWinShowSeqPane $seq
 	} else {
 	    SeqWinHideSeqPane $seq
@@ -272,6 +275,10 @@ proc SeqWinAdd {seq folder num} {
 proc SeqWinUpdate {seq folder num} {
     global seqwin flist
     
+    if {![winfo exist .sequences.pane$seq.lb]} {
+        # This happens when we are called early in initialization
+        SeqWinShowSeqPane $seq
+    }
     if {![info exist seqwin(folders,$seq)]} {
         set seqwin(folders,$seq) {}
     }
